/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#include <windows.h>
#include "utils.h"

INTEGER64
get_mem_size(void)
{
	MEMORYSTATUS ms;
    ZeroMemory(&ms, sizeof(MEMORYSTATUS));
    GlobalMemoryStatus(&ms);
	return ms.dwTotalPhys;
}
